@@ -3,7 +3,7 @@
 #########################################################
 #########################################################
 ##
-## Tripwire(R) 2.3 Open Source install script
+## Tripwire(R) 2.4 Open Source install script
 ##
 #########################################################
 #########################################################
@@ -162,12 +162,6 @@ CLR_POLICY_FILE="twpol.txt"
 # Default installation script configuration file.
 INSTALL_CONFIG_FILE="./install/install.cfg"
 
-# Name of the Readme file.
-README="README"
-
-# Name of the release notes.
-REL_NOTES="Release_Notes"
-
 # Relative path to dir that contains the pkg files.
 PKG_DIR="pkg"
 
@@ -247,7 +241,7 @@ done
 cat << END_OF_TEXT
 
 Installer program for:
-Tripwire(R) 2.3 Open Source
+Tripwire(R) 2.4 Open Source
 
 Copyright (C) 1998-2000 Tripwire (R) Security Systems, Inc.  Tripwire (R)
 is a registered trademark of the Purdue Research Foundation and is
@@ -286,7 +280,7 @@ EULA_PATH="$TWLICENSEFILE"
 
 if [ "$PROMPT" = "true" ] ; then
   echo
-  echo "LICENSE AGREEMENT for Tripwire(R) 2.3 Open Source"
+  echo "LICENSE AGREEMENT for Tripwire(R) 2.4 Open Source"
   echo
   echo "Please read the following license agreement.  You must accept the"
   echo "agreement to continue installing Tripwire."
@@ -401,15 +395,16 @@ echo
 TWMAILMETHOD=${TWMAILMETHOD:-'SENDMAIL'}
 if [ "$TWMAILMETHOD" = "SENDMAIL" ] ; then
 
-	TWMAILPROGRAM=${TWMAILPROGRAM:-'/usr/lib/sendmail -oi -t'}
-
-	TWMAILTEST=`echo ${TWMAILPROGRAM} | sed -e 's/ .*//'`
-
-	if [ -x ${TWMAILTEST} ] ; then
-        	echo "${TWMAILTEST} exists.  Continuing installation."
+	if [ -n "$TWMAILPROGRAM" ] ; then
+        	echo "${TWMAILPROGRAM} exists.  Continuing installation."
         	echo
 	else
-        	echo "$TWMAILPROGRAM does not exist.  Exiting."
+	        echo ""
+        	echo "*** No sendmail found. Edit install.cfg and set"
+		echo "*** TWMAILPROGRAM to full path to sendmail, or"
+		echo "*** change TWMAILMETHOD to SMTP and set SMTP"
+		echo "*** settings appropriately."
+		echo ""
         	exit 1
 	fi
 else
@@ -571,10 +566,8 @@ echo
 ## Make sure README_LOC and fil1 stay in sync.
 ##-------------------------------------------------------
 
-README_LOC=${TWDOCS}/$REL_NOTES
-
-f1=' ff=$README ; d="" ; dd=$TWDOCS ; rr=0444 '
-f2=' ff=$REL_NOTES ; d="" ; dd=$TWDOCS ; rr=0444 '
+#f1=' ff=$README ; d="" ; dd=$TWDOCS ; rr=0444 '
+#f2=' ff=$REL_NOTES ; d="" ; dd=$TWDOCS ; rr=0444 '
 f3=' ff=$TWLICENSEFILE ; d="" ; dd=$TWDOCS ; rr=0444 '
 #f4=' ff=tripwire ; d="/bin" ; dd=$TWBIN ; rr=0550 '
 #f5=' ff=twadmin ; d="/bin" ; dd=$TWBIN ; rr=0550 '
@@ -593,7 +586,7 @@ f10=' ff=${POLICYSRC} ; d="/policy" ; dd=$TWPOLICY ; rr=0640 '
 #f18=' ff=twprint.8 ; d="/man/man8" ; dd=$TWMAN/man8 ; rr=0444 '
 
 # Binaries and manpages are already installed by the install target
-loosefiles="f1 f2 f3 f8 f9 f10"
+loosefiles="f3 f8 f9 f10"
 
 for i in $loosefiles; do
 	eval "eval \"\$$i\""
@@ -921,14 +914,9 @@ The installation succeeded.
 
 Please refer to $README_LOC
 for release information and to the printed user documentation
-for further instructions on using Tripwire 2.3 Open Source.
+for further instructions on using Tripwire 2.4 Open Source.
 
 END_OF_TEXT
 
 cd "$START_DIR"
 
-##############################################################################
-# Copyright (C) 1998-2000 Tripwire (R) Security Systems, Inc.  Tripwire (R)
-# is a registered trademark of the Purdue Research Foundation and is
-# licensed exclusively to Tripwire (R) Security Systems, Inc.
-##############################################################################
