@@ -48,7 +48,7 @@
 #include "errno.h"
 
 
-#ifndef NDEBUG
+#ifdef DEBUG
 #define TSS_CCONV_VERBOSE    // Uncomment for verbose tracing!
 #endif
 
@@ -57,10 +57,18 @@
 // DEFINES
 //- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-#define TSS_USE_ICONV_CCONV16       HAS_ICONV
-#define TSS_USE_UCS2_CCONV16        (!(HAS_ICONV) && WCHAR_REP_IS_UCS2 && WCHAR_IS_16_BITS)
-#define TSS_USE_UCS2_CCONV32        (!(HAS_ICONV) && WCHAR_REP_IS_UCS2 && WCHAR_IS_32_BITS)
-
+/*
+ * ICONV conversion seems to be broken under Linux, so until
+ * this is fixed, we'll wing it ourselves - 20010310 PH
+ */
+#if 0
+#define TSS_USE_ICONV_CCONV16       HAVE_ICONV_H
+#define TSS_USE_UCS2_CCONV16        (!(HAVE_ICONV_H) && WCHAR_REP_IS_UCS2 && WCHAR_IS_16_BITS)
+#define TSS_USE_UCS2_CCONV32        (!(HAVE_ICONV_H) && WCHAR_REP_IS_UCS2 && WCHAR_IS_32_BITS)
+#else
+#define TSS_USE_UCS2_CCONV16        (WCHAR_REP_IS_UCS2 && WCHAR_IS_16_BITS)
+#define TSS_USE_UCS2_CCONV32        (WCHAR_REP_IS_UCS2 && WCHAR_IS_32_BITS)
+#endif
 
     #define ICONV_SOURCE_TYPE const char
 
