@@ -526,7 +526,7 @@ bool cCharEncoderUtil::IsWhiteSpace( TCHAR ch )
 
 bool cCharEncoderUtil::IsPrintable( TCHAR ch )
 {
-#if USE_CLIB_LOCALE
+#if USE_CLIB_LOCALE && !defined(__APPLE__)
 
     return( ! isprint( ch ) );    // kludge for KAI
 
@@ -828,7 +828,8 @@ bool cEncoder::OnlyOneCatagoryPerChar() const
             ach[0] = ch;
             for( sack_type::const_iterator atE = m_encodings.begin(); atE != m_encodings.end(); atE++ )
             {
-                if( (*atE)->NeedsEncoding( &ach[0], &ach[1] ) )
+		TSTRING::const_iterator first(&ach[0]), last(&ach[1]);
+                if( (*atE)->NeedsEncoding( first, last ) )
                 {
                     if( fFailedATest )
                         return false; // each char can only fail one test
