@@ -206,7 +206,7 @@ public:
 
 private:
 	mutable int															 mCurIndex;
-	mutable cHashTable<KEY_TYPE, VAL_TYPE, COMPARE_OP, CONVERTER>::node* mpCurNode;
+	mutable typename cHashTable<KEY_TYPE, VAL_TYPE, COMPARE_OP, CONVERTER>::node* mpCurNode;
     const cHashTable<KEY_TYPE, VAL_TYPE, COMPARE_OP, CONVERTER>&		 mHashTable;
 
 	// helper function
