@@ -77,7 +77,9 @@
 #include <sys/stat.h>
 #include <sys/wait.h>
 #include <time.h>
+#if defined(HAVE_MALLOC_H)
 #include <malloc.h>
+#endif
 #include <string.h>
 //#include <signal.h>
 #include "tw_signal.h"
@@ -951,8 +953,8 @@ int mask;
 			 * ignore any signals until child dies
 			 */
 			for(i = 0; i < MAX_SIGNAL; i++)
-#ifdef SIGCLD
-				if (i != SIGCLD)
+#ifdef SIGCHLD
+				if (i != SIGCHLD)
 #endif
 					savesig[i] = tw_sigign(i);
 			/*
