@@ -34,7 +34,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-# include <tw_config.h>
+# include <config.h>
 #endif
 
 #ifndef __PLATFORM_H
