@@ -38,13 +38,12 @@
 
 #include <signal.h>
 
-#if IS_LINUX && !IS_BSD		// IS_BSD is a hack, a better way should be found
-#if USES_GLIBC
-#include <bits/signum.h>
-#else
+#ifdef HAVE_SIGNUM_H
 #include <signum.h>		// the signal number constants
 #endif
-#endif IS_LINUX
+#ifdef HAVE_BITS_SIGNUM_H
+#include <bits/signum.h>
+#endif
 
 extern "C" {
 typedef void (*tw_sighandler_t)(int);
