@@ -2,7 +2,7 @@
 #define CONFIG_H
 
 #ifdef HAVE_CONFIG_H
-#include <tw_config.h>
+#include <config.h>
 #endif
 
 // define this if you want the library to throw exceptions when things go wrong
