@@ -64,7 +64,7 @@ unsigned int BitPrecision(unsigned long value)
 
 unsigned long Crop(unsigned long value, int size)
 {
-	if (size < 8*sizeof(value))
+	if (size < 8*(int)sizeof(value))
     	return (value & ((1L << size) - 1));
 	else
 		return value;
