@@ -92,7 +92,7 @@ word16 primeTable[maxPrimeTableSize] =
 void BuildPrimeTable()
 {
 	unsigned int p=primeTable[primeTableSize-1];
-	for (int i=primeTableSize; i<maxPrimeTableSize; i++)
+	for (unsigned int i=primeTableSize; i<maxPrimeTableSize; i++)
 	{
 		int j;
 		do
