@@ -12,11 +12,11 @@ public:
 
 	static void CorrectEndianess(word32 *out, const word32 *in, unsigned int byteCount)
 	{
-#ifdef CRYPTOPP_IS_LITTLE_ENDIAN
-		byteReverse(out, in, byteCount);
-#else
+#ifdef WORDS_BIGENDIAN
 		if (in!=out)
 			memcpy(out, in, byteCount);
+#else
+		byteReverse(out, in, byteCount);
 #endif
 	}
 
