@@ -269,7 +269,8 @@ void cFCOName::ParseString( const TCHAR* pszin )
 	
     mpPathName->ClearList();
 	
-	TSTRING::const_iterator at  = ( pszin + 0 );
+    TSTRING ats = const_cast<TCHAR *>(pszin + 0);
+    TSTRING::const_iterator at = ats.begin();
     TSTRING::const_iterator end = at;
     while ( *end ) ++end;               // NOTE: Find end
 
@@ -277,9 +278,9 @@ void cFCOName::ParseString( const TCHAR* pszin )
 	while ( at < end )
 	{
 		while ( !(*at == mDelimiter) && at < end )
-            at = tss::strinc( at );
+            at = *at ? at + 1 : at;
 
-        if ( at == beg && tss::strinc(at) >= end && at != pszin )
+        if ( at == beg && (*at ? at + 1 : at) >= end && at != ats.begin() )
             break;
 
 		cFCONameTblNode* pNode = 
@@ -287,7 +288,7 @@ void cFCOName::ParseString( const TCHAR* pszin )
 
         mpPathName->mNames.push_back( pNode );
 		
-        beg = ( at = tss::strinc( at ) );
+        beg = ( at = (*at ? at + 1 : at) );
 	}
 }
 
