@@ -32,7 +32,7 @@ BEGIN {
     %twcfgdirs = (
 
         ROOT                         => '',
-        POLFILE                      => $twpolicyloc,
+        POLFILE                      => 'policy/tw.pol',
         DBFILE                       => 'db/$(HOSTNAME).twd',
         REPORTFILE                   => 'report/$(HOSTNAME)-$(DATE).twr',
         SITEKEYFILE                  => $twsitekeyloc,
