@@ -439,7 +439,7 @@ bool cSMTPMailMessage::MailMessage()
         // do no encoding 
 
         // identify content type
-        sContentType += "7-bit";
+        sContentType += "7bit";
     }
 
     // send content type
