@@ -916,7 +916,7 @@ static void SendGmmsAlert(const TSTRING& gmmsProg, const TSTRING& gmmsOptions, c
         throw eGmmsError(eGmmsError::ERR_COULDNT_OPEN_PIPE, gmmsProg);
 
    // write the alert(s) to the process's standard-in.
-   if (_ftprintf(mpFile,  alerts.c_str()) < 0)
+   if (_ftprintf(mpFile, "%s", alerts.c_str()) < 0)
         throw eGmmsError(eGmmsError::ERR_COULDNT_WRITE_TO_PIPE, gmmsProg);
 
    // end the process by closing standard-in
