@@ -85,12 +85,11 @@
 #include <iomanip>
 #include <time.h>
 #include <fcntl.h>
-#if !IS_BSD
+#ifdef HAVE_WCHAR_H
 # include <wchar.h>
 #endif
-
-#if IS_UNIX
-    #include <unistd.h>
+#ifdef HAVE_UNISTD_H
+# include <unistd.h>
 #endif
 
 //=========================================================================
@@ -1675,7 +1674,7 @@ void OpenOutputFile( fixed_basic_ofstream<TCHAR>& out, const TSTRING& strFile )
     // we explicitly create the file so that we control the 
     // permissions on the new file.
 	unlink(narrowFilename.c_str());
-    int fd = open(narrowFilename.c_str(), O_CREAT|O_TRUNC|O_EXCL, 00600); 
+    int fd = open(narrowFilename.c_str(), O_RDWR|O_CREAT|O_TRUNC|O_EXCL, 00600);
     if (fd == -1 || close(fd) != 0) {
       throw eTextReportViewerFileOpen( strFile ); 
     }
