@@ -673,7 +673,7 @@ void cTWUtil::ReadConfigText(const TCHAR* filename, TSTRING& configText, cArchiv
     }
 
 #if 0	// XXX: This is broken, what the h*ll are they trying to write here? -PH
-    d.TraceDebug("Found a file header of type %d.\n", fileHeader.GetID());
+    d.TraceDebug("Found a file header of type %d.\n", fileHeader.GetEncoding());
 #endif
 
     // check for a mismatched header
@@ -778,7 +778,7 @@ void cTWUtil::ReadConfigText(cArchive &arch, TSTRING& configText, cArchive* pBag
     }
 
 #if 0	// XXX: This is broken, how can you convert a class to an int??? -PH
-    d.TraceDebug("Found a file header of type %d.\n", fileHeader.GetID());
+    d.TraceDebug("Found a file header of type %d.\n", fileHeader.GetEncoding());
 #endif
 
     // check for a mismatched header
@@ -996,6 +996,7 @@ const cElGamalSigPrivateKey* cTWUtil::CreatePrivateKey(cKeyFile& keyFile, const
     int count = 0;
 	while(count < 3)
 	{
+		cTWUtil::NoEcho noEcho;
 		switch (keyType)
         {
         case KEY_LOCAL:
@@ -1010,7 +1011,7 @@ const cElGamalSigPrivateKey* cTWUtil::CreatePrivateKey(cKeyFile& keyFile, const
             break;
         }
 
-		cTWUtil::GetStringNoEcho(passphrase);
+		cTWUtil::GetString(passphrase);
 		TCOUT << std::endl;
 
         // sleep to hinder brute force (dictionary, etc.) attacks
@@ -1071,6 +1072,7 @@ void cTWUtil::CreatePrivateKey(cPrivateKeyProxy& proxy, cKeyFile& keyFile, const
     int count = 0;
 	while(count < 3)
 	{
+		cTWUtil::NoEcho noEcho;
 		switch (keyType)
         {
         case KEY_LOCAL:
@@ -1085,7 +1087,7 @@ void cTWUtil::CreatePrivateKey(cPrivateKeyProxy& proxy, cKeyFile& keyFile, const
             break;
         }
 
-		cTWUtil::GetStringNoEcho(passphrase);
+		cTWUtil::GetString(passphrase);
 		TCOUT << std::endl;
 
         // sleep to hinder brute force (dictionary, etc.) attacks
@@ -1161,7 +1163,7 @@ void cTWUtil::GetString(wc16_string& ret)
 }
 
 
-void cTWUtil::GetStringNoEcho(wc16_string& ret)
+cTWUtil::NoEcho::NoEcho()
 {
     // set the terminal to no echo mode
     static struct termios Ntty;
@@ -1180,13 +1182,19 @@ void cTWUtil::GetStringNoEcho(wc16_string& ret)
     {
         ThrowAndAssert(eTWUtilEchoModeSet());
     }
+}
 
-    GetString(ret);
-    
+cTWUtil::NoEcho::~NoEcho() {
     tcsetattr( 0, TCSAFLUSH, &Otty);
     tw_signal(SIGINT, old_SIGINT);
     tw_signal(SIGQUIT, old_SIGQUIT);
 }
+
+void cTWUtil::GetStringNoEcho(wc16_string& ret)
+{
+	NoEcho noEcho;
+	GetString(ret);
+}
 #endif
 
 ///////////////////////////////////////////////////////////////////////////////
