@@ -98,6 +98,7 @@ public:
         MODE_ENCRYPT,
         MODE_EXAMINE,
         MODE_GENERATE_KEYS,
+        MODE_CHANGE_PASSPHRASES,
 		MODE_HELP,
 		MODE_HELP_ALL,
         MODE_VERSION,
@@ -116,6 +117,8 @@ public:
         CFG_FILE,
         SITEPASSPHRASE,
         LOCALPASSPHRASE,
+        SITEPASSPHRASEOLD,
+        LOCALPASSPHRASEOLD,
 
         PARAMS, // the final params
 
