@@ -47,7 +47,7 @@
 //=========================================================================
 
 #include <iomanip> 
-#if !IS_BSD
+#ifdef HAVE_WCHAR_H
 # include <wchar.h> 
 #endif
 
@@ -228,7 +228,7 @@ std::string util_ConvertMB( const std::string& sIn )
          // at gets incremented when used....
        )
     {
-        int nBytes = ::mblen( (char*)at, MB_CUR_MAX );
+        int nBytes = ::mblen( (char*)&at[0], MB_CUR_MAX );
         if ( nBytes == -1 )
         {
             d.TraceDebug( "Unrecognized Character: %c\n", *at );
