@@ -597,7 +597,7 @@ yyEncore:
 #ifdef YACC_WINDOWS
 	if (yystate >= Sizeof_yypact) 	/* simple state */
 #else /* YACC_WINDOWS */
-	if (yystate >= sizeof yypact/sizeof yypact[0]) 	/* simple state */
+	if (yystate >= (int)sizeof yypact/(int)sizeof yypact[0]) 	/* simple state */
 #endif /* YACC_WINDOWS */
 		yyi = yystate - YYDELTA;	/* reduce in any case */
 	else {
@@ -643,7 +643,7 @@ yyEncore:
 #ifdef YACC_WINDOWS
 		if (yystate >= Sizeof_yydef) 	/* simple state */
 #else /* YACC_WINDOWS */
-		if (yystate >= sizeof yydef /sizeof yydef[0])
+		if (yystate >= (int)sizeof yydef /(int)sizeof yydef[0])
 #endif /* YACC_WINDOWS */
 			goto yyError;
 		if ((yyi = yydef[yystate]) < 0)	 { /* default == reduce? */
@@ -1268,7 +1268,7 @@ yyError:
 #ifdef YACC_WINDOWS
 			if (*yyps >= Sizeof_yypact) 	/* simple state */
 #else /* YACC_WINDOWS */
-			if (*yyps >= sizeof yypact/sizeof yypact[0])
+			if (*yyps >= (int)sizeof yypact/(int)sizeof yypact[0])
 #endif /* YACC_WINDOWS */
 				continue;
 			yyp = &yyact[yypact[*yyps]];
